==> jbossws-shared-testsuite-4.1.0.Final.zip: java/org/jboss/test/ws/jaxws/jbws3552/EndpointIface.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2012, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.test.ws.jaxws.jbws3552;

import javax.jws.WebService;

@WebService
public interface EndpointIface {
    AdaptedObjectCA echoCA(AdaptedObjectCA ao);

    AdaptedObjectFA echoFA(AdaptedObjectFA ao);

    AdaptedObjectGA echoGA(AdaptedObjectGA ao);

    AdaptedObjectMA echoMA(AdaptedObjectMA ao);

    void throwExceptionCA() throws AdaptedExceptionCA;

    void throwExceptionFA() throws AdaptedExceptionFA;

    void throwExceptionGA() throws AdaptedExceptionGA;

    void throwExceptionMA() throws AdaptedExceptionMA;
}

==> jbossws-shared-testsuite-4.1.2.Final.zip: java/org/jboss/test/ws/jaxws/jbws3552/EndpointIface.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2012, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.test.ws.jaxws.jbws3552;

import javax.jws.WebService;

@WebService
public interface EndpointIface {
    AdaptedObjectCA echoCA(AdaptedObjectCA ao);

    AbstractObjectCA echoAbstractCA(AbstractObjectCA ao);

    AdaptedObjectFA echoFA(AdaptedObjectFA ao);

    AbstractObjectFA echoAbstractFA(AbstractObjectFA ao);

    AdaptedObjectGA echoGA(AdaptedObjectGA ao);

    AbstractObjectGA echoAbstractGA(AbstractObjectGA ao);

    AdaptedObjectMA echoMA(AdaptedObjectMA ao);

    AbstractObjectMA echoAbstractMA(AbstractObjectMA ao);

    void throwExceptionCA() throws AdaptedExceptionCA;

    void throwExtendedExceptionCA() throws ExtendedAdaptedExceptionCA;

    void throwExceptionFA() throws AdaptedExceptionFA;

    void throwExtendedExceptionFA() throws ExtendedAdaptedExceptionFA;

    void throwExceptionGA() throws AdaptedExceptionGA;

    void throwExtendedExceptionGA() throws ExtendedAdaptedExceptionGA;

    void throwExceptionMA() throws AdaptedExceptionMA;

    void throwExtendedExceptionMA() throws ExtendedAdaptedExceptionMA;
}
